@@ -9,7 +9,6 @@ from urllib.parse import urlparse
 
 import yaml
 import click
-import jinja2
 
 
 def _find_file_refs(obj, obj_loc: List[Union[str, int]] = None):
@@ -48,29 +47,16 @@ def _update_obj(obj, keys, sub_obj):
         raise ValueError("Cannot update obj with no keys.")
 
 
-def resolve(file_name, api, env, base_path):
+def resolve(file_name, pop_keys=None):
+
+    if pop_keys is None:
+        pop_keys = []
+
     root_file = pathlib.Path(file_name)
     if not root_file.exists() or root_file.is_dir():
         raise click.ClickException(f"No such file {root_file}")
 
-    jinja_env = jinja2.Environment(
-        undefined=jinja2.StrictUndefined,
-        variable_start_string="${",  # Use var syntax as ${ VARIABLE } so that param spec file is valid YAML.
-        variable_end_string="}",
-    )
-    default_config_vars = get_default_config_vars(api, env, base_path)
-    # Jinja vars set as implied (from CLI params) vars and environment vars
-    jinja_vars = {**default_config_vars, **os.environ}
-
-    def load_templated_yaml(template: str) -> Dict:
-        try:
-            # Sub jinja variables
-            yml_str = jinja_env.from_string(template).render(jinja_vars)
-        except jinja2.UndefinedError as exc:
-            raise click.ClickException(
-                f"{exc}\nHint: All jinja variables must be defined in an environment variable or one of {', '.join(default_config_vars.keys())}"
-            )
-
+    def load_templated_yaml(yml_str: str) -> Dict:
         try:
             return yaml.safe_load(yml_str)
 
@@ -82,19 +68,28 @@ def resolve(file_name, api, env, base_path):
     with root_file.open() as f:
         spec = load_templated_yaml(f.read())
 
-    file_refs = _find_file_refs(spec)
-    spec_dir = root_file.parent.absolute().resolve()
-    for keys, file_ref in file_refs:
-        file_path = spec_dir.joinpath(file_ref)
-        if not file_path.exists() or file_path.is_dir():
-            raise click.ClickException(f"Unable to resolve $ref {file_path} at {keys}")
-        with file_path.open() as f:
-            sub_spec = load_templated_yaml(f.read())
+    for key in pop_keys:
+        spec.pop(key, None)
 
-        spec = _update_obj(spec, keys, sub_spec)
+    # We need this while loop to handle the case where a file a $ref has a $ref inside it.
+    # The first loop replaces the outer ref, but also adds a ref.
+    # This Very Hacky Method can almost certainly be replaced with something more elegant.
+    # but... tomorrow is my last day, so it won't be me doing it.
+    while file_refs := _find_file_refs(spec):
+        spec_dir = root_file.parent.absolute().resolve()
+
+        for keys, file_ref in file_refs:
+            file_path = spec_dir.joinpath(file_ref)
+            if not file_path.exists() or file_path.is_dir():
+                raise click.ClickException(f"Unable to resolve $ref {file_path} at {keys}")
+            with file_path.open() as f:
+                sub_spec = load_templated_yaml(f.read())
+
+            spec = _update_obj(spec, keys, sub_spec)
     return spec
 
 
+
 def host(env):
     sub_domain = "api" if env == "prod" else f"{env}.api"
     return f"https://{sub_domain}.service.nhs.uk"
@@ -102,13 +97,3 @@ def host(env):
 
 def url(env, base_path):
     return f"{host(env)}/{base_path}"
-
-
-def get_default_config_vars(api, env, base_path):
-    return {
-        "BASE_PATH": base_path,
-        "API": api,
-        "ENVIRONMENT": env,
-        "HOST": host(env),
-        "BASE_URL": url(env, base_path),
-    }
